@@ -9,16 +9,21 @@ class Registry:
     pages = RegistryItem()
     documents = RegistryItem()
     images = RegistryItem()
+    media = RegistryItem()
+    collections = RegistryItem()
     snippets = RegistryItem()
     streamfield_blocks = RegistryItem()
     django_models = RegistryItem()
     settings = RegistryItem()
+    field_middlewares = {}
 
     # The items in the registry that should be lazy loaded.
     lazy_types = (
         "pages",
         "documents",
         "images",
+        "media",
+        "collections",
         "snippets",
         "django_models",
         "settings",
@@ -33,6 +38,7 @@ class Registry:
         models.update(self.pages)
         models.update(self.documents)
         models.update(self.images)
+        models.update(self.collections)
         models.update(self.snippets)
         models.update(self.django_models)
         models.update(self.settings)
@@ -44,6 +50,7 @@ class Registry:
         models.update(self.pages)
         models.update(self.documents)
         models.update(self.images)
+        models.update(self.collections)
         models.update(self.snippets)
         models.update(self.streamfield_blocks)
         models.update(self.django_models)
